@@ -23,7 +23,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.24';
+$VERSION = '1.25';
 
 sub ProcessICC($$);
 sub ProcessICC_Profile($$$);
@@ -536,7 +536,7 @@ sub HexID($)
 # Returns: Formatted value or undefined if format not supported
 # Notes: The following types are handled by BinaryTables:
 #  chromaticityType, colorantTableType, measurementType, viewingConditionsType
-# The following types are not currently handled (most are large tables):
+# The following types are currently not handled (most are large tables):
 #  curveType, lut16Type, lut8Type, lutAtoBType, lutBtoAType, namedColor2Type,
 #  parametricCurveType, profileSeqDescType, responseCurveSet16Type
 # The multiLocalizedUnicodeType must be handled by the calling routine.
@@ -790,7 +790,7 @@ sub ProcessICC_Profile($$$)
     return 0 if $dirLen < 4;
 
     # extract binary ICC_Profile data block if binary mode or requested
-    if ((($exifTool->{OPTIONS}{Binary} and not $exifTool->{EXCL_TAG_LOOKUP}{icc_profile}) or
+    if ((($exifTool->{TAGS_FROM_FILE} and not $exifTool->{EXCL_TAG_LOOKUP}{icc_profile}) or
         $exifTool->{REQ_TAG_LOOKUP}{icc_profile}) and
         # (don't extract from AsShotICCProfile or CurrentICCProfile)
         (not $$dirInfo{Name} or $$dirInfo{Name} eq 'ICC_Profile'))
